#!/bin/sh

# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24
# 
#  (c) Copyright IBM Corp. 2006,2007.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************
# 
# ************************************************************************
#  Update Monitor Dashboard 6.0.2.1 to iFix4 level
# ************************************************************************

# define fixpack-specific variables
MON_FIXPACK_LEVEL=iFix4
MON_FIXPACK=6.0.2.1-WBI-MONITOR-$MON_FIXPACK_LEVEL
MON_FIXPACK_INST=./$MON_FIXPACK.install
MON_FIXPACK_BACKUP=$MON_FIXPACK_INST/backups/dashboard
MON_FIXPACK_STAMP=$MON_FIXPACK.version

# define input prompts       
MON_HOME_PROMPT="Type the path to the WebSphere Business Monitor installation directory"
WAS_HOME_PROMPT="Type the path to the WebSphere Application Server installation directory"
PROFILE_PROMPT="Type the path to the profile that the contains the Portal Server"
PORTAL_HOME_PROMPT="Type the path to the Portal Server installation directory"
CONFIG_PORT_PROMPT="Type the port number used to access the WebSphere Portal configuration utility"
WPS_ID_PROMPT="Type the user ID for the Portal Admin user"
WPS_PW_PROMPT="Type the password for the Portal Admin user"

# set defaults 
WARN_ONLY=no
MON_HOME=/usr/IBM/WebSphere/Monitor
PROFILE_NAME=wp_profile
WAS_HOME=/usr/IBM/WAS
WPS_HOME=/usr/IBM/PortalServer
PROFILE_HOME=$WAS_HOME/profiles/$PROFILE_NAME
PORTAL_SERVER=WebSphere_Portal
ADMIN_ID=wpsadmin
ADMIN_PW=wpsadmin


# ************************************************************************
# Begin function definitions
# ************************************************************************

# ************************************************************************
# Back up file being replaced, then copy in new one
# Don't copy file that doesn't exist in target
# ************************************************************************
backupandreplace ()
{
  echo $0: $*
  replacefile=${1##*/}
  if [ -f $2/$replacefile ]
  then
    if [ ! -d $MON_FIXPACK_BACKUP/$3 ]
    then
      mkdir -p $MON_FIXPACK_BACKUP/$3
      checkCmdErr $?
    fi

    if [ ! -f $MON_FIXPACK_BACKUP/$3/$replacefile ]
    then
      cp -f $2/$replacefile $MON_FIXPACK_BACKUP/$3 >> $MY_LOG 2>&1
      checkCmdErr $?
    else
      echo "Backup already created for $replacefile in $MON_FIXPACK_BACKUP/$3, not overwriting"
      logecho "Backup already created for $replacefile in $MON_FIXPACK_BACKUP/$3, not overwriting" >> $MY_LOG
    fi

    cp -f $1 $2 >> $MY_LOG 2>&1
    checkCmdErr $?
  fi
}

# ************************************************************************
# Write messages to log file
# ************************************************************************
logecho ()
{
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
  echo $1 >> $MY_LOG
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
  date +%T >> $MY_LOG
  return 0
}

# ************************************************************************
# Copy iFix version file ("stamp") and backups to Monitor home
# ************************************************************************
copystampandbackups ()
{
  echo Copying backups and version info to Monitor home.
  logecho "Copying backups and version info to Monitor home."

  cp -f ./version/*.* $MON_FIXPACK_INST >> $MY_LOG 2>&1

  MON_FIXPACK_DIR=$MON_HOME/update
  if [ ! -d $MON_FIXPACK_DIR ]
  then
    mkdir -p $MON_FIXPACK_DIR
  fi
  cp -f -R $MON_FIXPACK_INST $MON_FIXPACK_DIR >> $MY_LOG 2>&1
}

# ************************************************************************
# Copy log file to Monitor home
# ************************************************************************
copylog ()
{
   if [ "$MON_HOME" != "" ]
   then
      MON_LOG_DIR=$MON_HOME/update/$MON_FIXPACK_INST/logs
      if [ ! -d $MON_LOG_DIR ] 
      then 
         mkdir -p $MON_LOG_DIR
      fi 
      cp -f $MY_LOG $MON_LOG_DIR
   fi
}

# ************************************************************************
# Handle command failures
# ************************************************************************
cmdFailed()
{
  echo +++ Error: \'$CMD\' returned $1
  if [ $WARN_ONLY = "yes" ]
  then
    return $1
  fi 
  failed 8
}

# ************************************************************************
# Check return code from command execution
# ************************************************************************
checkCmdErr()
{
  if [ $1 -ne 0 ]  
  then
    cmdFailed $1
  fi
}

# ************************************************************************
# Print failure message and get out 
# ************************************************************************
failed()
{
    echo Update failed! 
    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
    echo Update failed! >> $MY_LOG
    echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
    date >> $MY_LOG
    copylog
    exit $1
}

# ************************************************************************
# End function definitions
# ************************************************************************


# ************************************************************************
# Begin main code 
# ************************************************************************

# set up logs directory
MY_DIR=`pwd`
if [ ! -e  $MY_DIR/logs ] 
then 
   mkdir -p $MY_DIR/logs
fi
MY_LOG=$MY_DIR/logs/dashboard.log

echo Start Monitor Dashboard 6.0.2.1 $MON_FIXPACK_LEVEL update...
logecho "Start Monitor Dashboard 6.0.2.1 $MON_FIXPACK_LEVEL update..."

# get Monitor home
echo $MON_HOME_PROMPT [enter=$MON_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   MON_HOME=$RESPONSE
fi
if [ ! -d $MON_HOME ]
then 
   echo +++ Error: Monitor home - $MON_HOME does NOT exist!
   logecho "+++ Error: Monitor home - $MON_HOME does NOT exist!"
   MON_HOME=
   failed 8
fi
       
# get WAS variables
echo $WAS_HOME_PROMPT [enter=$WAS_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   WAS_HOME=$RESPONSE
fi
if [ ! -d $WAS_HOME ]
then 
   echo +++ Error: WAS home - $WAS_HOME does NOT exist!
   logecho "+++ Error: WAS home - $WAS_HOME does NOT exist!"
   failed 8
fi
PROFILE_HOME=$WAS_HOME/profiles/$PROFILE_NAME
echo $PROFILE_PROMPT [enter=$PROFILE_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   PROFILE_HOME=$RESPONSE
fi
if [ ! -d $PROFILE_HOME ]
then 
   echo +++ Error: Profile home - $PROFILE_HOME does NOT exist!
   logecho "+++ Error: Profile home - $PROFILE_HOME does NOT exist!"
   failed 8
fi

# get Portal variables
echo $PORTAL_HOME_PROMPT [enter=$WPS_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   WPS_HOME=$RESPONSE
fi
if [ ! -d $WPS_HOME ]
then 
   echo +++ Error: Portal home - $WPS_HOME does NOT exist!
   logecho "+++ Error: Portal home - $WPS_HOME does NOT exist!"
   failed 8
fi
echo $WPS_ID_PROMPT [enter=$ADMIN_ID ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   ADMIN_ID=$RESPONSE
fi
echo $WPS_PW_PROMPT [enter=$ADMIN_PW ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   ADMIN_PW=$RESPONSE
fi

# stop the server so we can copy files
echo Stopping server $PORTAL_SERVER...
logecho "Stopping server $PORTAL_SERVER..."
CMD="$PROFILE_HOME/bin/stopServer.sh $PORTAL_SERVER -username $ADMIN_ID -password $ADMIN_PW"
$CMD >>$MY_LOG 2>&1 

# ************************************************************************
# copy jar files
# ************************************************************************
# Back up existing files to be replaced and replace
for jarfile in ./jars/*
do
  backupandreplace $jarfile ${WAS_HOME}/lib jars
done
checkCmdErr $?

# ************************************************************************
# copy our stamp and backups to the Monitor home directory
# ************************************************************************
copystampandbackups

echo Starting server $PORTAL_SERVER...
logecho "Starting server $PORTAL_SERVER..."
CMD="$PROFILE_HOME/bin/startServer.sh $PORTAL_SERVER -username $ADMIN_ID -password $ADMIN_PW"
$CMD >>$MY_LOG 2>&1 
checkCmdErr $?

echo Update finished.
logecho "Update finished."
copylog
exit 0
